#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Tests for `scopus.AuthorSearch` module."""

from collections import namedtuple
from nose.tools import assert_equal

from pybliometrics.scopus import AuthorSearch

s1 = AuthorSearch('authlast(selten) and authfirst(reinhard)', refresh=True)
s2 = AuthorSearch('authlast(selten)', download=False)


def test_authors():
    order = 'eid surname initials givenname affiliation documents '\
            'affiliation_id city country areas'
    Author = namedtuple('Author', order)
    expected = [Author(eid='9-s2.0-6602907525', surname='Selten',
        initials='R.', givenname='Reinhard', affiliation='Universität Bonn',
        documents='74', affiliation_id='60007493', city='Bonn',
        country='Germany', areas='ECON (73); MATH (19); BUSI (16)')]
    assert_equal(s1.authors, expected)


def test_authors_nodownload():
    assert_equal(s2.authors, None)


def test_results_size():
    assert_equal(s1.get_results_size(), 1)
    assert_equal(s2.get_results_size(), 25)
